==> qt-creator-opensource-src-4.13.3.zip: qt-creator-opensource-src-4.13.3/src/plugins/qmldesigner/designercore/instances/interactiveconnectionmanager.h <==
/****************************************************************************
**
** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "connectionmanager.h"

namespace QmlDesigner {

class InteractiveConnectionManager : public ConnectionManager
{
public:
    InteractiveConnectionManager();

    void setUp(NodeInstanceServerProxy *nodeInstanceServerProxy,
               const QString &qrcMappingString,
               ProjectExplorer::Target *target) override;

    void showCannotConnectToPuppetWarningAndSwitchToEditMode() override;

protected:
    void dispatchCommand(const QVariant &command, Connection &connection) override;

private:
    void puppetTimeout(Connection &connection);
    void puppetAlive(Connection &connection);
};

} // namespace QmlDesigner

==> qt-creator-opensource-src-6.0.0.zip: qt-creator-opensource-src-6.0.0/src/plugins/qmldesigner/designercore/instances/interactiveconnectionmanager.h <==
/****************************************************************************
**
** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "connectionmanager.h"

namespace QmlDesigner {

class InteractiveConnectionManager : public ConnectionManager
{
    Q_OBJECT

public:
    InteractiveConnectionManager();

    void setUp(NodeInstanceServerInterface *nodeInstanceServer,
               const QString &qrcMappingString,
               ProjectExplorer::Target *target,
               AbstractView *view) override;

    void shutDown() override;

    void showCannotConnectToPuppetWarningAndSwitchToEditMode() override;

protected:
    void dispatchCommand(const QVariant &command, Connection &connection) override;

private:
    void puppetTimeout(Connection &connection);
    void puppetAlive(Connection &connection);

private:
    AbstractView *m_view{};
};

} // namespace QmlDesigner
